@@ -699,11 +699,13 @@ class Dialect(metaclass=_Dialect):
             exp.VariancePop,
         },
         exp.DataType.Type.INT: {
+            exp.Ascii,
             exp.Ceil,
             exp.DatetimeDiff,
             exp.DateDiff,
             exp.TimestampDiff,
             exp.TimeDiff,
+            exp.Unicode,
             exp.DateToDi,
             exp.Levenshtein,
             exp.Sign,
