@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import typing as t
 
 from sqlglot import exp
 from sqlglot.dialects.dialect import NormalizationStrategy
@@ -8,6 +7,26 @@ from sqlglot.dialects.tsql import TSQL
 from sqlglot.tokens import TokenType
 
 
+def _cap_data_type_precision(expression: exp.DataType, max_precision: int = 6) -> exp.DataType:
+    """
+    Cap the precision of to a maximum of `max_precision` digits.
+    If no precision is specified, default to `max_precision`.
+    """
+
+    precision_param = expression.find(exp.DataTypeParam)
+
+    if precision_param and precision_param.this.is_int:
+        current_precision = precision_param.this.to_py()
+        target_precision = min(current_precision, max_precision)
+    else:
+        target_precision = max_precision
+
+    return exp.DataType(
+        this=expression.this,
+        expressions=[exp.DataTypeParam(this=exp.Literal.number(target_precision))],
+    )
+
+
 class Fabric(TSQL):
     """
     Microsoft Fabric Data Warehouse dialect that inherits from T-SQL.
@@ -59,7 +78,7 @@ class Fabric(TSQL):
             exp.DataType.Type.SMALLMONEY: "DECIMAL",
             exp.DataType.Type.TIMESTAMP: "DATETIME2",
             exp.DataType.Type.TIMESTAMPNTZ: "DATETIME2",
-            exp.DataType.Type.TIMESTAMPTZ: "DATETIMEOFFSET",
+            exp.DataType.Type.TIMESTAMPTZ: "DATETIME2",
             exp.DataType.Type.TINYINT: "SMALLINT",
             exp.DataType.Type.UTINYINT: "SMALLINT",
             exp.DataType.Type.UUID: "VARBINARY(MAX)",
@@ -73,37 +92,54 @@ class Fabric(TSQL):
                 expression.is_type(*exp.DataType.TEMPORAL_TYPES)
                 and expression.this != exp.DataType.Type.DATE
             ):
-                # Get the current precision (first expression if it exists)
-                precision_param = expression.find(exp.DataTypeParam)
-                target_precision = 6
-
-                if precision_param and precision_param.this.is_int:
-                    # Cap precision at 6
-                    current_precision = precision_param.this.to_py()
-                    target_precision = min(current_precision, 6)
-                else:
-                    # If precision exists but is not an integer, default to 6
-                    target_precision = 6
-
-                # Create a new expression with the target precision
-                expression = exp.DataType(
-                    this=expression.this,
-                    expressions=[exp.DataTypeParam(this=exp.Literal.number(target_precision))],
-                )
+                # Create a new expression with the capped precision
+                expression = _cap_data_type_precision(expression)
 
             return super().datatype_sql(expression)
 
-        def cast_sql(self, expression: exp.Cast, safe_prefix: t.Optional[str] = None) -> str:
-            # Special handling for TIMESTAMPTZ casts in Fabric
-            if expression.to and expression.to.is_type(exp.DataType.Type.TIMESTAMPTZ):
-                attimezone = expression.find_ancestor(exp.AtTimeZone, exp.Select)
-                if not isinstance(attimezone, exp.AtTimeZone):
-                    # We're not inside an AT TIME ZONE, so wrap the cast in AT TIME ZONE 'UTC'
-                    at_time_zone = exp.AtTimeZone(this=expression, zone=exp.Literal.string("UTC"))
-                    return self.sql(at_time_zone)
+        def cast_sql(self, expression: exp.Cast, safe_prefix: str | None = None) -> str:
+            # Cast to DATETIMEOFFSET if inside an AT TIME ZONE expression
+            # https://learn.microsoft.com/en-us/sql/t-sql/data-types/datetimeoffset-transact-sql#microsoft-fabric-support
+            if expression.is_type(exp.DataType.Type.TIMESTAMPTZ):
+                at_time_zone = expression.find_ancestor(exp.AtTimeZone, exp.Select)
+
+                # Return normal cast, if the expression is not in an AT TIME ZONE context
+                if not isinstance(at_time_zone, exp.AtTimeZone):
+                    return super().cast_sql(expression, safe_prefix)
+
+                # Get the precision from the original TIMESTAMPTZ cast and cap it to 6
+                capped_data_type = _cap_data_type_precision(expression.to, max_precision=6)
+                precision = capped_data_type.find(exp.DataTypeParam)
+                precision_value = (
+                    precision.this.to_py() if precision and precision.this.is_int else 6
+                )
+
+                # Do the cast explicitly to bypass sqlglot's default handling
+                datetimeoffset = f"CAST({expression.this} AS DATETIMEOFFSET({precision_value}))"
+
+                return self.sql(datetimeoffset)
 
             return super().cast_sql(expression, safe_prefix)
 
+        def attimezone_sql(self, expression: exp.AtTimeZone) -> str:
+            # Wrap the AT TIME ZONE expression in a cast to DATETIME2 if it contains a TIMESTAMPTZ
+            ## https://learn.microsoft.com/en-us/sql/t-sql/data-types/datetimeoffset-transact-sql#microsoft-fabric-support
+            timestamptz_cast = expression.find(exp.Cast)
+            if timestamptz_cast and timestamptz_cast.to.is_type(exp.DataType.Type.TIMESTAMPTZ):
+                # Get the precision from the original TIMESTAMPTZ cast and cap it to 6
+                data_type = timestamptz_cast.to
+                capped_data_type = _cap_data_type_precision(data_type, max_precision=6)
+                precision_param = capped_data_type.find(exp.DataTypeParam)
+                precision = precision_param.this.to_py() if precision_param else 6
+
+                # Generate the AT TIME ZONE expression (which will handle the inner cast conversion)
+                at_time_zone_sql = super().attimezone_sql(expression)
+
+                # Wrap it in an outer cast to DATETIME2
+                return f"CAST({at_time_zone_sql} AS DATETIME2({precision}))"
+
+            return super().attimezone_sql(expression)
+
         def unixtotime_sql(self, expression: exp.UnixToTime) -> str:
             scale = expression.args.get("scale")
             timestamp = expression.this
