@@ -561,6 +561,7 @@ class Postgres(Dialect):
         ARRAY_CONCAT_IS_VAR_LEN = False
         SUPPORTS_MEDIAN = False
         ARRAY_SIZE_DIM_REQUIRED = True
+        SUPPORTS_BETWEEN_FLAGS = True
 
         SUPPORTED_JSON_PATH_PARTS = {
             exp.JSONPathKey,
@@ -817,3 +818,29 @@ class Postgres(Dialect):
         def placeholder_sql(self, expression: exp.Placeholder) -> str:
             this = f"({expression.name})" if expression.this else ""
             return f"{self.NAMED_PLACEHOLDER_TOKEN}{this}s"
+
+        def arraycontains_sql(self, expression: exp.ArrayContains) -> str:
+            # Convert DuckDB's LIST_CONTAINS(array, value) to PostgreSQL
+            # DuckDB behavior:
+            #   - LIST_CONTAINS([1,2,3], 2) -> true
+            #   - LIST_CONTAINS([1,2,3], 4) -> false
+            #   - LIST_CONTAINS([1,2,NULL], 4) -> false (not NULL)
+            #   - LIST_CONTAINS([1,2,3], NULL) -> NULL
+            #
+            # PostgreSQL equivalent: CASE WHEN value IS NULL THEN NULL
+            #                            ELSE COALESCE(value = ANY(array), FALSE) END
+            value = expression.expression
+            array = expression.this
+
+            coalesce_expr = exp.Coalesce(
+                this=value.eq(exp.Any(this=exp.paren(expression=array, copy=False))),
+                expressions=[exp.false()],
+            )
+
+            case_expr = (
+                exp.Case()
+                .when(exp.Is(this=value, expression=exp.null()), exp.null(), copy=False)
+                .else_(coalesce_expr, copy=False)
+            )
+
+            return self.sql(case_expr)
