@@ -288,6 +288,42 @@ class TestTSQL(Validator):
             "CREATE TABLE [db].[tbl] ([a] INTEGER)",
         )
 
+        # Test VARCHAR without precision conversion to VARCHAR(1)
+        self.validate_identity(
+            "CREATE TABLE t (col VARCHAR)",
+            "CREATE TABLE t (col VARCHAR(1))",
+        )
+
+        # Test VARCHAR with existing precision should remain unchanged
+        self.validate_identity("CREATE TABLE t (col VARCHAR(50))")
+
+        # Test CHAR without precision conversion to CHAR(1)
+        self.validate_identity(
+            "CREATE TABLE t (col CHAR)",
+            "CREATE TABLE t (col CHAR(1))",
+        )
+
+        # Test CHAR with existing precision should remain unchanged
+        self.validate_identity("CREATE TABLE t (col CHAR(10))")
+
+        # Test cross-dialect conversion: non-TSQL VARCHAR -> TSQL VARCHAR(MAX)
+        self.validate_all(
+            "CREATE TABLE t (col VARCHAR(MAX))",
+            read={
+                "postgres": "CREATE TABLE t (col VARCHAR)",
+                "tsql": "CREATE TABLE t (col VARCHAR(MAX))",
+            },
+        )
+
+        # Test cross-dialect conversion: non-TSQL CHAR -> TSQL CHAR(MAX)
+        self.validate_all(
+            "CREATE TABLE t (col CHAR(MAX))",
+            read={
+                "postgres": "CREATE TABLE t (col CHAR)",
+                "tsql": "CREATE TABLE t (col CHAR(MAX))",
+            },
+        )
+
         self.validate_identity("SELECT a = 1", "SELECT 1 AS a").selects[0].assert_is(
             exp.Alias
         ).args["alias"].assert_is(exp.Identifier)
@@ -494,7 +530,7 @@ class TestTSQL(Validator):
         self.validate_identity("CREATE PROCEDURE test(@v1 INTEGER = 1, @v2 CHAR(1) = 'c')")
         self.validate_identity("DECLARE @v1 AS INTEGER = 1, @v2 AS CHAR(1) = 'c'")
 
-        for output in ("OUT", "OUTPUT", "READ_ONLY"):
+        for output in ("OUT", "OUTPUT", "READONLY"):
             self.validate_identity(
                 f"CREATE PROCEDURE test(@v1 INTEGER = 1 {output}, @v2 CHAR(1) {output})"
             )
